@@ -7,7 +7,7 @@ __copyright__ = 'Copyright 2013, Kyle Laplante'
 __date__ = '06-20-2013'
 
 __license__ = 'GPL'
-__version__  = '1.1'
+__version__  = '1.2'
 __email__ = 'kyle.laplante@gmail.com'
 
 
@@ -18,17 +18,30 @@ class IndexConfigParserException(Exception):
 class IndexConfigParser(dict):
 
     '''A class to parse configuration files that require indexing.
+This class returns a dictionary that you can call to retrieve items
+from your config file.
+
 To use this parser to its full potential create config files in the
 following format for example:
+
+(Example config file)
+
+# Home server
 server_1 = somename
 ip_1     = 1.2.3.4
+location_1 = san jose
 
+# Remote server
 server_2 = someothername
 ip_2     = 4.3.2.1
+location_2 = boston
 
+# Universal configs
 universal_key = something universal
+my_username = kyle
 
-You keep raising the indexed number as much as you want.
+
+You can keep raising the indexed number as much as you want.
 The way to use this library is to pick a config definition
 that you know will be different for each index. In this case I would
 use "server" as the "defining key" and that would make each server name
@@ -40,7 +53,23 @@ keys = this is a list of the keys that are not indexed
        (used for universal purposes)
 index_keys = this is a list of all the keys that are indexed
              (this is generated based on the defining key)
-all_keys = this is a list of all the keys combined '''
+all_keys = this is a list of all the keys combined 
+
+Examples:
+
+import IndexConfigParser
+
+(The following code will print the dictionaries of each index key)
+icp = IndexConfigParser.IndexConfigParser("/home/kyle/config.cfg", "server")
+for key in icp.index_keys:
+    print icp[key]
+
+(The following is how to call a specific key in the index key dict)
+icp = IndexConfigParser.IndexConfigParser("/home/kyle/config.cfg", "server")
+var = "somename"
+icp[var]["ip"]
+(Using the example config file above this would return "1.2.3.4")
+'''
 
     def __getitem__(self, key):
         try:
